Package: skewr
Title: Visualize Intensities Produced by Illumina's Human Methylation
        450k BeadChip
Version: 1.44.0
Authors@R: c(person("Ryan", "Putney", role = c("cre", "aut"), email =
        "ryanputney@gmail.com"), person("Steven", "Eschrich", role =
        "aut"), person("Anders", "Berglund", role = "aut"))
Description: The skewr package is a tool for visualizing the output of
        the Illumina Human Methylation 450k BeadChip to aid in quality
        control. It creates a panel of nine plots. Six of the plots
        represent the density of either the methylated intensity or the
        unmethylated intensity given by one of three subsets of the
        485,577 total probes. These subsets include Type I-red, Type
        I-green, and Type II.The remaining three distributions give the
        density of the Beta-values for these same three subsets. Each
        of the nine plots optionally displays the distributions of the
        "rs" SNP probes and the probes associated with imprinted genes
        as series of 'tick' marks located above the x-axis.
Depends: R (>= 3.1.1), methylumi, wateRmelon, mixsmsn,
        IlluminaHumanMethylation450kmanifest
Imports: minfi, S4Vectors (>= 0.19.1), RColorBrewer
Suggests: GEOquery, knitr, minfiData
VignetteBuilder: knitr
License: GPL-2
biocViews: DNAMethylation, TwoChannel, Preprocessing, QualityControl
Author: Ryan Putney [cre, aut], Steven Eschrich [aut], Anders Berglund
        [aut]
Maintainer: Ryan Putney <ryanputney@gmail.com>
git_url: https://git.bioconductor.org/packages/skewr
git_branch: RELEASE_3_23
git_last_commit: 33814ce
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:47:49 UTC; biocbuild
